/****************************************************************************
** Meta object code from reading C++ file 'identitymanager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kidentitymanagement-26.04.3/src/core/identitymanager.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'identitymanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN23KIdentityManagementCore15IdentityManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto KIdentityManagementCore::IdentityManager::qt_create_metaobjectdata<qt_meta_tag_ZN23KIdentityManagementCore15IdentityManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KIdentityManagementCore::IdentityManager",
        "changed",
        "",
        "identitiesWereChanged",
        "uoid",
        "KIdentityManagementCore::Identity",
        "ident",
        "identityChanged",
        "deleted",
        "added",
        "needToReloadIdentitySettings",
        "identitiesChanged",
        "id",
        "slotRollback",
        "slotIdentitiesChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'changed'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'identitiesWereChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'changed'
        QtMocHelpers::SignalData<void(uint)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 4 },
        }}),
        // Signal 'changed'
        QtMocHelpers::SignalData<void(const KIdentityManagementCore::Identity &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'identityChanged'
        QtMocHelpers::SignalData<void(const KIdentityManagementCore::Identity &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'deleted'
        QtMocHelpers::SignalData<void(uint)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 4 },
        }}),
        // Signal 'added'
        QtMocHelpers::SignalData<void(const KIdentityManagementCore::Identity &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'needToReloadIdentitySettings'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'identitiesChanged'
        QtMocHelpers::SignalData<void(const QString &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 },
        }}),
        // Slot 'slotRollback'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotIdentitiesChanged'
        QtMocHelpers::SlotData<void(const QString &)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 12 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<IdentityManager, qt_meta_tag_ZN23KIdentityManagementCore15IdentityManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KIdentityManagementCore::IdentityManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23KIdentityManagementCore15IdentityManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23KIdentityManagementCore15IdentityManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN23KIdentityManagementCore15IdentityManagerE_t>.metaTypes,
    nullptr
} };

void KIdentityManagementCore::IdentityManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<IdentityManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->changed(); break;
        case 1: _t->identitiesWereChanged(); break;
        case 2: _t->changed((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 3: _t->changed((*reinterpret_cast<std::add_pointer_t<KIdentityManagementCore::Identity>>(_a[1]))); break;
        case 4: _t->identityChanged((*reinterpret_cast<std::add_pointer_t<KIdentityManagementCore::Identity>>(_a[1]))); break;
        case 5: _t->deleted((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 6: _t->added((*reinterpret_cast<std::add_pointer_t<KIdentityManagementCore::Identity>>(_a[1]))); break;
        case 7: _t->needToReloadIdentitySettings(); break;
        case 8: _t->identitiesChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->slotRollback(); break;
        case 10: _t->d->slotIdentitiesChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (IdentityManager::*)()>(_a, &IdentityManager::changed, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (IdentityManager::*)()>(_a, &IdentityManager::identitiesWereChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (IdentityManager::*)(uint )>(_a, &IdentityManager::changed, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (IdentityManager::*)(const KIdentityManagementCore::Identity & )>(_a, &IdentityManager::changed, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (IdentityManager::*)(const KIdentityManagementCore::Identity & )>(_a, &IdentityManager::identityChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (IdentityManager::*)(uint )>(_a, &IdentityManager::deleted, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (IdentityManager::*)(const KIdentityManagementCore::Identity & )>(_a, &IdentityManager::added, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (IdentityManager::*)()>(_a, &IdentityManager::needToReloadIdentitySettings, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (IdentityManager::*)(const QString & )>(_a, &IdentityManager::identitiesChanged, 8))
            return;
    }
}

const QMetaObject *KIdentityManagementCore::IdentityManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KIdentityManagementCore::IdentityManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23KIdentityManagementCore15IdentityManagerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KIdentityManagementCore::IdentityManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void KIdentityManagementCore::IdentityManager::changed()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KIdentityManagementCore::IdentityManager::identitiesWereChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KIdentityManagementCore::IdentityManager::changed(uint _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void KIdentityManagementCore::IdentityManager::changed(const KIdentityManagementCore::Identity & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void KIdentityManagementCore::IdentityManager::identityChanged(const KIdentityManagementCore::Identity & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void KIdentityManagementCore::IdentityManager::deleted(uint _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void KIdentityManagementCore::IdentityManager::added(const KIdentityManagementCore::Identity & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void KIdentityManagementCore::IdentityManager::needToReloadIdentitySettings()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void KIdentityManagementCore::IdentityManager::identitiesChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}
QT_WARNING_POP
