/****************************************************************************
** Meta object code from reading C++ file 'identity.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kidentitymanagement-26.04.3/src/core/identity.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'identity.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN23KIdentityManagementCore8IdentityE_t {};
} // unnamed namespace

template <> constexpr inline auto KIdentityManagementCore::Identity::qt_create_metaobjectdata<qt_meta_tag_ZN23KIdentityManagementCore8IdentityE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KIdentityManagementCore::Identity",
        "mailingAllowed",
        "identityName",
        "fullName",
        "organization",
        "pgpEncryptionKey",
        "pgpSigningKey",
        "smimeEncryptionKey",
        "smimeSigningKey",
        "preferredCryptoMessageFormat",
        "primaryEmailAddress",
        "emailAliases",
        "vCardFile",
        "fullEmailAddr",
        "replyToAddr",
        "bcc",
        "cc",
        "attachVcard",
        "autocorrectionLanguage",
        "disabledFcc",
        "pgpAutoSign",
        "pgpAutoEncrypt",
        "autocryptEnabled",
        "autocryptPrefer",
        "encryptionOverride",
        "warnNotSign",
        "warnNotEncrypt",
        "defaultDomainName",
        "signature",
        "Signature",
        "signatureText",
        "signatureIsInlinedHtml",
        "transport",
        "fcc",
        "drafts",
        "templates",
        "dictionary",
        "xface",
        "isXFaceEnabled",
        "face",
        "isFaceEnabled",
        "uoid",
        "isNull",
        "spam",
        "disabledSpam"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'mailingAllowed'
        QtMocHelpers::PropertyData<bool>(1, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'identityName'
        QtMocHelpers::PropertyData<QString>(2, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'fullName'
        QtMocHelpers::PropertyData<QString>(3, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'organization'
        QtMocHelpers::PropertyData<QString>(4, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'pgpEncryptionKey'
        QtMocHelpers::PropertyData<QByteArray>(5, QMetaType::QByteArray, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'pgpSigningKey'
        QtMocHelpers::PropertyData<QByteArray>(6, QMetaType::QByteArray, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'smimeEncryptionKey'
        QtMocHelpers::PropertyData<QByteArray>(7, QMetaType::QByteArray, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'smimeSigningKey'
        QtMocHelpers::PropertyData<QByteArray>(8, QMetaType::QByteArray, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'preferredCryptoMessageFormat'
        QtMocHelpers::PropertyData<QString>(9, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'primaryEmailAddress'
        QtMocHelpers::PropertyData<QString>(10, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'emailAliases'
        QtMocHelpers::PropertyData<QStringList>(11, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'vCardFile'
        QtMocHelpers::PropertyData<QString>(12, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'fullEmailAddr'
        QtMocHelpers::PropertyData<QString>(13, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'replyToAddr'
        QtMocHelpers::PropertyData<QString>(14, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'bcc'
        QtMocHelpers::PropertyData<QString>(15, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'cc'
        QtMocHelpers::PropertyData<QString>(16, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'attachVcard'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'autocorrectionLanguage'
        QtMocHelpers::PropertyData<QString>(18, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'disabledFcc'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'pgpAutoSign'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'pgpAutoEncrypt'
        QtMocHelpers::PropertyData<bool>(21, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'autocryptEnabled'
        QtMocHelpers::PropertyData<bool>(22, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'autocryptPrefer'
        QtMocHelpers::PropertyData<bool>(23, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'encryptionOverride'
        QtMocHelpers::PropertyData<bool>(24, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'warnNotSign'
        QtMocHelpers::PropertyData<bool>(25, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'warnNotEncrypt'
        QtMocHelpers::PropertyData<bool>(26, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'defaultDomainName'
        QtMocHelpers::PropertyData<QString>(27, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'signature'
        QtMocHelpers::PropertyData<Signature>(28, 0x80000000 | 29, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'signatureText'
        QtMocHelpers::PropertyData<QString>(30, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'signatureIsInlinedHtml'
        QtMocHelpers::PropertyData<bool>(31, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'transport'
        QtMocHelpers::PropertyData<QString>(32, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'fcc'
        QtMocHelpers::PropertyData<QString>(33, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'drafts'
        QtMocHelpers::PropertyData<QString>(34, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'templates'
        QtMocHelpers::PropertyData<QString>(35, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'dictionary'
        QtMocHelpers::PropertyData<QString>(36, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'xface'
        QtMocHelpers::PropertyData<QString>(37, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'isXFaceEnabled'
        QtMocHelpers::PropertyData<bool>(38, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'face'
        QtMocHelpers::PropertyData<QString>(39, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'isFaceEnabled'
        QtMocHelpers::PropertyData<bool>(40, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'uoid'
        QtMocHelpers::PropertyData<uint>(41, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'isNull'
        QtMocHelpers::PropertyData<bool>(42, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'spam'
        QtMocHelpers::PropertyData<QString>(43, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'disabledSpam'
        QtMocHelpers::PropertyData<bool>(44, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Identity, qt_meta_tag_ZN23KIdentityManagementCore8IdentityE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KIdentityManagementCore::Identity::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23KIdentityManagementCore8IdentityE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23KIdentityManagementCore8IdentityE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN23KIdentityManagementCore8IdentityE_t>.metaTypes,
    nullptr
} };

void KIdentityManagementCore::Identity::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<Identity *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->mailingAllowed(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->identityName(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->fullName(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->organization(); break;
        case 4: *reinterpret_cast<QByteArray*>(_v) = _t->pgpEncryptionKey(); break;
        case 5: *reinterpret_cast<QByteArray*>(_v) = _t->pgpSigningKey(); break;
        case 6: *reinterpret_cast<QByteArray*>(_v) = _t->smimeEncryptionKey(); break;
        case 7: *reinterpret_cast<QByteArray*>(_v) = _t->smimeSigningKey(); break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->preferredCryptoMessageFormat(); break;
        case 9: *reinterpret_cast<QString*>(_v) = _t->primaryEmailAddress(); break;
        case 10: *reinterpret_cast<QStringList*>(_v) = _t->emailAliases(); break;
        case 11: *reinterpret_cast<QString*>(_v) = _t->vCardFile(); break;
        case 12: *reinterpret_cast<QString*>(_v) = _t->fullEmailAddr(); break;
        case 13: *reinterpret_cast<QString*>(_v) = _t->replyToAddr(); break;
        case 14: *reinterpret_cast<QString*>(_v) = _t->bcc(); break;
        case 15: *reinterpret_cast<QString*>(_v) = _t->cc(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->attachVcard(); break;
        case 17: *reinterpret_cast<QString*>(_v) = _t->autocorrectionLanguage(); break;
        case 18: *reinterpret_cast<bool*>(_v) = _t->disabledFcc(); break;
        case 19: *reinterpret_cast<bool*>(_v) = _t->pgpAutoSign(); break;
        case 20: *reinterpret_cast<bool*>(_v) = _t->pgpAutoEncrypt(); break;
        case 21: *reinterpret_cast<bool*>(_v) = _t->autocryptEnabled(); break;
        case 22: *reinterpret_cast<bool*>(_v) = _t->autocryptPrefer(); break;
        case 23: *reinterpret_cast<bool*>(_v) = _t->encryptionOverride(); break;
        case 24: *reinterpret_cast<bool*>(_v) = _t->warnNotSign(); break;
        case 25: *reinterpret_cast<bool*>(_v) = _t->warnNotEncrypt(); break;
        case 26: *reinterpret_cast<QString*>(_v) = _t->defaultDomainName(); break;
        case 27: *reinterpret_cast<Signature*>(_v) = _t->signature(); break;
        case 28: *reinterpret_cast<QString*>(_v) = _t->signatureText(); break;
        case 29: *reinterpret_cast<bool*>(_v) = _t->signatureIsInlinedHtml(); break;
        case 30: *reinterpret_cast<QString*>(_v) = _t->transport(); break;
        case 31: *reinterpret_cast<QString*>(_v) = _t->fcc(); break;
        case 32: *reinterpret_cast<QString*>(_v) = _t->drafts(); break;
        case 33: *reinterpret_cast<QString*>(_v) = _t->templates(); break;
        case 34: *reinterpret_cast<QString*>(_v) = _t->dictionary(); break;
        case 35: *reinterpret_cast<QString*>(_v) = _t->xface(); break;
        case 36: *reinterpret_cast<bool*>(_v) = _t->isXFaceEnabled(); break;
        case 37: *reinterpret_cast<QString*>(_v) = _t->face(); break;
        case 38: *reinterpret_cast<bool*>(_v) = _t->isFaceEnabled(); break;
        case 39: *reinterpret_cast<uint*>(_v) = _t->uoid(); break;
        case 40: *reinterpret_cast<bool*>(_v) = _t->isNull(); break;
        case 41: *reinterpret_cast<QString*>(_v) = _t->spam(); break;
        case 42: *reinterpret_cast<bool*>(_v) = _t->disabledSpam(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setIdentityName(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setFullName(*reinterpret_cast<QString*>(_v)); break;
        case 3: _t->setOrganization(*reinterpret_cast<QString*>(_v)); break;
        case 4: _t->setPGPEncryptionKey(*reinterpret_cast<QByteArray*>(_v)); break;
        case 5: _t->setPGPSigningKey(*reinterpret_cast<QByteArray*>(_v)); break;
        case 6: _t->setSMIMEEncryptionKey(*reinterpret_cast<QByteArray*>(_v)); break;
        case 7: _t->setSMIMESigningKey(*reinterpret_cast<QByteArray*>(_v)); break;
        case 8: _t->setPreferredCryptoMessageFormat(*reinterpret_cast<QString*>(_v)); break;
        case 9: _t->setPrimaryEmailAddress(*reinterpret_cast<QString*>(_v)); break;
        case 10: _t->setEmailAliases(*reinterpret_cast<QStringList*>(_v)); break;
        case 11: _t->setVCardFile(*reinterpret_cast<QString*>(_v)); break;
        case 13: _t->setReplyToAddr(*reinterpret_cast<QString*>(_v)); break;
        case 14: _t->setBcc(*reinterpret_cast<QString*>(_v)); break;
        case 15: _t->setCc(*reinterpret_cast<QString*>(_v)); break;
        case 16: _t->setAttachVcard(*reinterpret_cast<bool*>(_v)); break;
        case 17: _t->setAutocorrectionLanguage(*reinterpret_cast<QString*>(_v)); break;
        case 18: _t->setDisabledFcc(*reinterpret_cast<bool*>(_v)); break;
        case 19: _t->setPgpAutoSign(*reinterpret_cast<bool*>(_v)); break;
        case 20: _t->setPgpAutoEncrypt(*reinterpret_cast<bool*>(_v)); break;
        case 21: _t->setAutocryptEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 22: _t->setAutocryptPrefer(*reinterpret_cast<bool*>(_v)); break;
        case 23: _t->setEncryptionOverride(*reinterpret_cast<bool*>(_v)); break;
        case 24: _t->setWarnNotSign(*reinterpret_cast<bool*>(_v)); break;
        case 25: _t->setWarnNotEncrypt(*reinterpret_cast<bool*>(_v)); break;
        case 26: _t->setDefaultDomainName(*reinterpret_cast<QString*>(_v)); break;
        case 27: _t->setSignature(*reinterpret_cast<Signature*>(_v)); break;
        case 30: _t->setTransport(*reinterpret_cast<QString*>(_v)); break;
        case 31: _t->setFcc(*reinterpret_cast<QString*>(_v)); break;
        case 32: _t->setDrafts(*reinterpret_cast<QString*>(_v)); break;
        case 33: _t->setTemplates(*reinterpret_cast<QString*>(_v)); break;
        case 34: _t->setDictionary(*reinterpret_cast<QString*>(_v)); break;
        case 35: _t->setXFace(*reinterpret_cast<QString*>(_v)); break;
        case 36: _t->setXFaceEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 37: _t->setFace(*reinterpret_cast<QString*>(_v)); break;
        case 38: _t->setFaceEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 41: _t->setSpam(*reinterpret_cast<QString*>(_v)); break;
        case 42: _t->setDisabledSpam(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}
QT_WARNING_POP
