// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "kidentitymanagementcore_debug.h"


Q_LOGGING_CATEGORY(KIDENTITYMANAGEMENT_LOG, "org.kde.pim.kidentitymanagement", QtInfoMsg)

